using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace SystemBrowser
{
  /// <summary>
  /// FormMenuToolBar is used as a design-time host for
  /// the application's toolbar and statusbar. At runtime,
  /// these elements are moved over onto FormMain. 
  /// FormMenuToolBar is useful because it contains all the
  /// event handling code for the menu and toolbar, obviating
  /// the need to put that code in FormMain.
  /// </summary>
  public partial class FormMenuToolBar : Form
  {
    public FormMenuToolBar()
    {
      InitializeComponent();
    }

    public void ShowAddress(string theAddress)
    {
      if (theAddress == null) theAddress = string.Empty;
      textBoxAddress.Text = theAddress;
      textBoxAddress.SelectionStart = textBoxAddress.Text.Length;
    }

    private void menuItemFileExit_Click(object sender, EventArgs e)
    {
      Application.Exit();
    }

    private void menuItemViewIcons_Click(object sender, EventArgs e)
    {
      menuItemViewIcons.Checked = true;
      menuItemViewDetails.Checked = false;
      FireViewIcons();
    }

    private void menuItemViewDetails_Click(object sender, EventArgs e)
    {
      menuItemViewIcons.Checked = false;
      menuItemViewDetails.Checked = true;
      FireViewDetails();
    }

    private void textBoxAddress_KeyPress(object sender, KeyPressEventArgs e)
    {
      if (e.KeyChar == '\r')
      {
        e.Handled = true; // to prevent Windows from beeping
        FireAddressChanged(textBoxAddress.Text);
      }
    }

    private void toolBar_ButtonClick(object sender, ToolBarButtonClickEventArgs e)
    {
      if (e.Button == toolBarButtonUp)
        FireUpClicked();
    }

    #region Events
    public delegate void UniversalHandler();

    public event UniversalHandler ViewIcons;
    void FireViewIcons()
    {
      if (ViewIcons != null)
        ViewIcons();
    }

    public event UniversalHandler ViewDetails;
    void FireViewDetails()
    {
      if (ViewDetails != null)
        ViewDetails();
    }

    public event UniversalHandler UpClicked;
    void FireUpClicked()
    {
      if (UpClicked != null)
        UpClicked();
    }

    public delegate void AddressChangedHandler(string theNewAddress);
    public event AddressChangedHandler AddressChanged;
    void FireAddressChanged(string theNewAddress)
    {
      if (AddressChanged != null)
        AddressChanged(theNewAddress);
    }
    #endregion

  }
}