using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace SystemBrowser
{
  public partial class ContentFileList : UserControl
  {
    // ImageList indexes, for images placed next to file and folder names
    const int ImageFolder = 0;
    const int ImageFile = 1;

    FormMain formMain;

    private NavigatorFolders navigatorFolders;
    public NavigatorFolders NavigatorFolders
    {
      get { return navigatorFolders; }
      set { navigatorFolders = value; }
    }

    public ContentFileList()
    {
      InitializeComponent();
    }

    public ContentFileList(FormMain theFormMain) 
      : this()
    {
      formMain = theFormMain;
    }

    // show a list of all the folders and files in a folder
    public void Populate(string theFolder)
    {
      listViewFiles.BeginUpdate();
      listViewFiles.Items.Clear();

      // first the subdirectories
      foreach (string directory in Directory.GetDirectories(theFolder))
      {
        string name = Path.GetFileName(directory);
        ListViewItem item = listViewFiles.Items.Add(name, ImageFolder);
        item.Tag = directory;
      }

      // then the files
      foreach (string filePath in Directory.GetFiles(theFolder))
        Add(filePath);

      listViewFiles.EndUpdate();
    }

    // add a file to the list
    public void Add(string theFilePath)
    {
      if (!File.Exists(theFilePath)) return;
      string name = Path.GetFileName(theFilePath);
      ListViewItem item = new ListViewItem(name, ImageFile);
      item.Tag = theFilePath;
      FileInfo fileInfo = new FileInfo(theFilePath);
      long length = fileInfo.Length / 1024;
      if (length < 1)
        length = 1;
      string size = string.Format("{0:#,##0} KB", length);
      string type = fileInfo.Extension;
      if (type.StartsWith("."))
        type = type.Substring(1);
      DateTime dateModified = fileInfo.LastWriteTime;
      item.SubItems.Add(size);
      item.SubItems.Add(type);
      item.SubItems.Add(dateModified.ToString("yyyy-MM-dd HH:mm:ss"));
      listViewFiles.Items.Add(item);
    }

    // organize file list showing only names
    public void ShowIcons()
    {
      listViewFiles.View = View.SmallIcon;
    }

    // organize file list showing details
    public void ShowDetails()
    {
      listViewFiles.View = View.Details;
    }

    public void Clear()
    {
      listViewFiles.Items.Clear();
    }

    // show info about a file to the user
    void IndicateFileInfo()
    {
      if (listViewFiles.FocusedItem == null) return;
      if (listViewFiles.FocusedItem.ImageIndex == ImageFolder)
      {
        formMain.ShowStatusBarMessage(""); // erase the status bar message
        return;
      }

      string filePath = listViewFiles.FocusedItem.Tag as string;
      if (!File.Exists(filePath)) return;
      FileInfo fileInfo = new FileInfo(filePath);
      long length = fileInfo.Length / 1024;
      if (length < 1)
        length = 1;
      string size = string.Format("File size: {0:#,##0} KB   {1}", length, filePath);
      formMain.ShowStatusBarMessage(size);  // show a new status bar message
    }

    private void listViewFiles_DoubleClick(object sender, EventArgs e)
    {
      if (listViewFiles.SelectedItems.Count == 0) return;
      string filePath = listViewFiles.SelectedItems[0].Tag as string;
      formMain.ShowAddress(filePath);
      navigatorFolders.SelectFolder(filePath);
    }
  }
}
