using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace SystemBrowser
{
  public partial class FormMain : Form
  {
    NavigatorFolders navigatorFolders;
    ContentFileList contentFileList;

    public FormMain()
    {
      InitializeComponent();

      contentFileList = new ContentFileList(this);
      navigatorFolders = new NavigatorFolders(this);

      contentFileList.NavigatorFolders = navigatorFolders;
      navigatorFolders.ContentFileList = contentFileList;

      panelLeft.Controls.Clear();
      panelLeft.Controls.Add(navigatorFolders);
      navigatorFolders.Dock = DockStyle.Fill;

      panelRight.Controls.Clear();
      panelRight.Controls.Add(contentFileList);
      contentFileList.Dock = DockStyle.Fill;
    }

    public void ShowAddress(string theAddress)
    {
      if (theAddress == null) theAddress = string.Empty;
      textBoxAddress.Text = theAddress;
      textBoxAddress.SelectionStart = textBoxAddress.Text.Length;
    }

    public void ShowStatusBarMessage(string theMessage)
    {
      labelMessage.Text = theMessage;
      labelMessage.Update();
    }

    private void textBoxAddress_KeyPress(object sender, KeyPressEventArgs e)
    {
      if (e.KeyChar == '\r')
      {
        e.Handled = true; // to prevent Windows from beeping
        navigatorFolders.SelectFolder(textBoxAddress.Text);
      }
    }

    private void toolBar_ButtonClick(object sender, ToolBarButtonClickEventArgs e)
    {
      if (e.Button == toolBarButtonUp)
        navigatorFolders.SelectParentFolder();
    }

    private void menuItemViewDetails_Click(object sender, EventArgs e)
    {
      menuItemViewDetails.Checked = true;
      menuItemViewIcons.Checked = false;
      contentFileList.ShowDetails();
    }

    private void menuItemViewIcons_Click(object sender, EventArgs e)
    {
      menuItemViewDetails.Checked = false;
      menuItemViewIcons.Checked = true;
      contentFileList.ShowIcons();
    }

    private void FormMain_Load(object sender, EventArgs e)
    {
      // show initial folders and files
      const string initialFolder = @"c:\";
      navigatorFolders.Populate(initialFolder);
      contentFileList.Populate(initialFolder);
      ShowStatusBarMessage(initialFolder);
      textBoxAddress.Text = initialFolder;
    }
  }
}